@@ -158,9 +158,9 @@ L_1way_ANOVA <- function(data, group, contrast1=NULL, contrast2=NULL, verb=TRUE)
     "versus group means model = ", round(S_cont1_meansc,3),
     "\n Support for contrast 1 versus contrast 2 ", if (is.null(nulfg)) "(quadratic) ", "= ", round(S_cont_12,3),
      "\n\nOverall analysis F(",dfv[1],",",dfv[2],") = ", round(Fval,3),
-    ", p = ", round(Pval,5), ", eta-squared = ", round(eta_sq,3),
+    ", p = ", format.pval(Pval,4), ", eta-squared = ", round(eta_sq,3),
     "\nContrast 1 F(1,",dfv[2],") = ", round(Fval_c1,3),
-    ", p = ", round(Pval_c1,5), "\n ")
+    ", p = ", format.pval(Pval_c1,4), "\n ")
   df1 <- c(1, m1$Df[2])
   invisible(list(S.12c = S_12c, S.12 = S_12, S.1mc = S_cont1_meansc,
                S.1m = S_cont1_means, S.cont.12 = S_cont_12,
